import { LLMProvider } from '../constants/llmProvider';
import { ToolResponse } from '../models/toolResponse';
import { IBedrockToolOutput, ICustomParams, IGraph, IGraphSession, ILLMProviderHandler, ILocalTool, IOpenAIToolOutput } from '../types';
/**
 * Class representing the XpanderClient used to interact with xpanderAI tools.
 */
export declare class XpanderClient {
    agentKey: string;
    agentUrl: string;
    toolsCache: any;
    graphsCache: any | IGraph;
    toolsFromExternal: boolean;
    localTools: ILocalTool[];
    protected llmProviderHandler: ILLMProviderHandler;
    protected graphSession: any | IGraphSession;
    /**
     * @internal
     */
    _customParams: ICustomParams | undefined;
    /**
     * Provides a list of valid LLM providers.
     * @returns Array of valid provider names.
     */
    static get validProviders(): string[];
    /**
     * Constructs a new XpanderClient instance.
     * @param agentKey - The API key for the agent.
     * @param agentUrl - The URL for the agent.
     * @param llmProvider - The LLM provider to use.
     * @param localTools - Local tools to append into the tools list.
     * @param tools - Pass existing xpanderAI tools to the client instead of fetching.
     * @param customParams - Optional custom parameters for enhanced context.
     * @throws Will throw an error if an invalid LLM provider is specified.
     */
    constructor(agentKey: string, agentUrl: string, llmProvider: LLMProvider, localTools?: ILocalTool[], tools?: any[] | IOpenAIToolOutput[] | IBedrockToolOutput[], customParams?: any | ICustomParams);
    /**
     * Initializes a new graph session with the provided prompt.
     * @param {string} [prompt=''] - The prompt to initialize the session with.
     * @returns {void}
     */
    startSession(prompt?: string): void;
    /**
     * Retrieves the appropriate tools for the current graph session.
     *
     * @param {any[] | IOpenAIToolOutput[] | IBedrockToolOutput[]} tools - Array of available tools.
     *
     * @returns {any[] | IOpenAIToolOutput[] | IBedrockToolOutput[]} A subset of tools based on the graph session and prompt group.
     * @throws {Error} If graphs are not loaded or the graph session is not initiated properly.
     */
    getToolsForGraphsSession(tools: any[] | IOpenAIToolOutput[] | IBedrockToolOutput[]): any[] | IOpenAIToolOutput[] | IBedrockToolOutput[];
    /**
     * Loads the tools available from the xpanderAI agent.
     * @returns Array of tools.
     * @throws Will throw an error if the tools cannot be loaded.
     */
    loadXpanderTools(): any[];
    /**
     * Loads the graphs associated with the agent from the server.
     *
     * @returns {IGraph} The loaded graphs, cached if previously loaded.
     * @throws {Error} If the graphs cannot be loaded or are malformed.
     */
    private loadXpanderGraphs;
    /**
     * Retrieves custom params in the right format for agents service, only if they exist (passed by constructor).
     * For internal use only.
     * @internal
     * @returns - Empty object or formatted customParams.
     */
    _getCustomParamsIfExist: () => {
        organization_id: string;
        connectors: {
            id: string;
            operation_ids: string[];
        }[];
    } | {
        organization_id?: undefined;
        connectors?: undefined;
    };
    /**
     * Retrieves the tools for the current or specified LLM provider.
     * @param {LLMProvider} llmProvider (Optional) The LLM provider to use.
     * @returns Array of tools.
     */
    tools(llmProvider?: LLMProvider): any[] | IOpenAIToolOutput[] | IBedrockToolOutput[];
    /**
     * Invokes the tools based on the tool selector response.
     * @param toolSelectorResponse - The response from the tool selector.
     * @param llmProvider - (Optional) The LLM provider to use.
     * @returns Array of tool responses.
     */
    xpanderToolCall(toolSelectorResponse: any, llmProvider?: string): ToolResponse[];
    /**
     * Initializes the LLM provider handler for the specified provider.
     * @param llmProvider - The LLM provider to initialize.
     * @returns The initialized LLM provider handler.
     * @throws Will throw an error if the handler for the specified provider cannot be found.
     */
    private initLLMProviderHandler;
    /**
     * Makes a synchronous request.
     * @param method - The HTTP method to use.
     * @param url - The URL to send the request to.
     * @param data - The data to include in the request.
     * @returns The response from the request.
     * @throws Will throw an error if the request fails.
     */
    private syncRequest;
    /**
     * Adds local tools to the client.
     * @param tools - Array of local tools to add.
     */
    addLocalTools(tools: any[] | ILocalTool[]): void;
    /**
     * Invokes a single tool with the given tool ID and payload.
     * @param toolId - The ID of the tool to invoke.
     * @param payload - The payload to pass to the tool.
     * @returns The result of the tool invocation.
     * @throws Will throw an error if the tool implementation is not found.
     */
    xpanderSingleToolInvoke(toolId: string, payload?: any): string;
    /**
     * Sets a parameter in the current graph session.
     * @param {'previousNode' | 'prompt' | 'promptGroup'} param - The parameter to set, either 'previousNode' or 'prompt'.
     * @param {any} value - The value to assign to the specified parameter.
     * @returns {void}
     */
    setGraphSessionParam(param: 'previousNode' | 'prompt' | 'promptGroup', value: any): void;
    /**
     * Gets a parameter in the current graph session.
     * @param {'previousNode' | 'prompt' | 'promptGroup' | 'pgSwitchAllowed'} param - The parameter to get, either 'previousNode' or 'prompt'.
     * @returns {any}
     */
    getGraphSessionParam(param: 'previousNode' | 'prompt' | 'promptGroup' | 'pgSwitchAllowed'): any;
    /**
     * Retrieves the tool names mapping for the current LLM provider.
     * @returns A record of tool names mapping.
     */
    get toolsNamesMapping(): Record<string, string>;
}
